@@ -43,7 +43,7 @@ na.seadec <- function(x, algorithm = "interpolation" , ...) {
   
   # Multivariate Input Handling (loop through all columns)
   # No imputation code in this part. 
-  if (!is.null( dim(data)[2])  ) {
+  if (!is.null( dim(data)[2]) && dim(data)[2] > 1 ) {
     for (i in 1:dim(data)[2]) {
       #if imputing a column does not work (mostly because it is not numeric) the column is left unchanged
       tryCatch(data[,i] <- na.seadec(data[ ,i], algorithm, ...), error=function(cond) {
@@ -65,18 +65,26 @@ na.seadec <- function(x, algorithm = "interpolation" , ...) {
       return(data)
     }
     
+    if(!is.null(dim(data)[2])&&!dim(data)[2]==1)
+    {stop("Wrong input type for parameter x")}
+    
+    # Altering multivariate objects with 1 column (which are essentially univariate) to be dim = NULL
+    if (!is.null(dim(data)[2])) {
+      data <- data[,1]
+    }
+    
     if(!is.numeric(data))
     {stop("Input x is not numeric")}
     
-    if(!is.null(dim(data)))
-    {stop("Wrong input type for parameter x")}
-    
     if(frequency(data)==1) {
       warning("No seasonality information for dataset found, going on without decomposition")
       data <- apply.base.algorithm(data, algorithm = algorithm,...)
       return(data)
     }
     
+    ## End Input Check
+    
+    
     ##
     ## Imputation Code
     ##
@@ -99,6 +107,18 @@ na.seadec <- function(x, algorithm = "interpolation" , ...) {
     # add seasonality 
     data <- ts.imputed + stl$time.series[,1]
     
+    ## End Imputation Code
+    
+    
+    ##
+    ## Ouput Formatting
+    ##
+    
+    # Give back the object originally supplied to the function (necessary for multivariate input with only 1 column)
+    if (!is.null(dim(x)[2])) {
+      x[,1] <- data
+      return(x)
+    }
     
     return(data)
   }
